@@ -122,6 +122,11 @@ class ResultsHandler:
         Tries to filter ids and stuff,
         that is knowing to change over time in descriptions.
         """
+        if description is None:
+            return ''
+
+        if not isinstance(description, str):
+            return description
 
         description = re.sub(r'id="[^"]*"', "", description)
         description = re.sub(r"id='[^']*'", "", description)
@@ -168,12 +173,24 @@ class ResultsHandler:
             elif url_parts.hostname == self.moodle_domain:
                 module_modname = 'cookie_mod-description-' + original_module_modname
 
+            fist_guess_filename = url
+            if fist_guess_filename.startswith('data:image/'):
+                file_extension_guess = 'png'
+                if len(fist_guess_filename.split(';')) > 1:
+                    if len(fist_guess_filename.split(';')[0].split('/')) > 1:
+                        file_extension_guess = fist_guess_filename.split(';')[0].split('/')[1]
+
+                fist_guess_filename = 'inline_image.' + file_extension_guess
+
+            if len(fist_guess_filename) > 254:
+                fist_guess_filename = fist_guess_filename[:254]
+
             new_file = File(
                 module_id=module_id,
                 section_name=section_name,
                 module_name=module_name,
                 content_filepath=content_filepath,
-                content_filename=url,
+                content_filename=fist_guess_filename,
                 content_fileurl=url,
                 content_filesize=0,
                 content_timemodified=0,
@@ -240,7 +257,8 @@ class ResultsHandler:
             if content_fileurl == '' and module_modname.startswith(('url', 'index_mod', 'cookie_mod')):
                 continue
 
-            if module_modname.startswith('index_mod'):
+            # Add the extention condition to avoid renaming pdf files or other downloaded content from moodle pages.
+            if module_modname.startswith('index_mod') and content_filename.endswith('.html'):
                 content_filename = module_name
 
             hash_description = None
